@@ -159,7 +159,7 @@ def reindex_year_df_rel_col(df):
             delta = last_val_date - relcol_date
             if delta.days < 10:
                 relyear1 = (relyear + pd.DateOffset(years=1)).year
-                relyear1 = [x for x in df if str(relyear1) in x]
+                relyear1 = [x for x in df.columns if relyear1 == x]
                 if len(relyear1) > 0:
                     return relyear1[0]
             else:
